@@ -39,33 +39,44 @@ private:
 };
 
 
-struct anchor_parser: anchor_type<anchor, string>
+// We would like to re-use the string parser in implementation
+// of the anchor parser. Since the return types of our post()
+// functions are not covariant, we will need to "rename" the
+// anchor::post function before we can mix the two implementation
+// together. For more information see the mix-in example.
+//
+struct anchor_parser_base: parsers::anchor<anchor, string>
+{
+  virtual ::anchor
+  post_anchor () = 0;
+
+  virtual ::anchor
+  post ()
+  {
+    return post_anchor ();
+  }
+};
+
+struct anchor_parser: anchor_parser_base, xml_schema::string
 {
   virtual void
-  href (const string& uri)
+  href (const std::string& uri)
   {
     uri_ = uri;
   }
 
-  virtual void
-  _characters (const string& s)
+  virtual ::anchor
+  post_anchor ()
   {
-    text_ = s;
-  }
-
-  virtual anchor
-  post ()
-  {
-    return anchor (text_, uri_);
+    return ::anchor (xml_schema::string::post (), uri_);
   }
 
 private:
-  string uri_;
-  string text_;
+  std::string uri_;
 };
 
 
-struct text_parser: text_type<void, anchor>
+struct text_parser: parsers::text<void, anchor>
 {
   virtual void
   a (const anchor& a)
@@ -75,7 +86,7 @@ struct text_parser: text_type<void, anchor>
   }
 
   virtual void
-  _any_characters (const string& s)
+  _any_characters (const xml_schema::ro_string& s)
   {
     cout << s;
   }
